@@ -93,8 +93,8 @@ public:
    *
    * @{
    */
-  double getIndex(int state1, int state2) const throw (BadIntException);
-  double getIndex(const std::string& state1, const std::string& state2) const throw (BadCharException);
+  double getIndex(int state1, int state2) const;
+  double getIndex(const std::string& state1, const std::string& state2) const;
   const Alphabet* getAlphabet() const { return alphabet_; }
   LinearMatrix<double>* getIndexMatrix() const;
   bool isSymmetric() const { return true; }
