@@ -78,7 +78,7 @@ class AbstractIAlignment:
      * @param sc     The sequence container to update.
      * @throw Exception If the file is not in the specified format.
      */
-    virtual void readAlignment(std::istream& input, SiteContainer& sc) const throw (Exception)
+    virtual void readAlignment(std::istream& input, SiteContainer& sc) const
     {
       appendAlignmentFromStream(input, sc);
     }
@@ -90,19 +90,19 @@ class AbstractIAlignment:
      * @param sc    The sequence container to update.
      * @throw Exception If the file is not in the specified format.
      */
-    virtual void readAlignment(const std::string& path, SiteContainer& sc) const throw (Exception)
+    virtual void readAlignment(const std::string& path, SiteContainer& sc) const
     {
       appendAlignmentFromFile(path, sc);
     }
  
     virtual
-    AlignedSequenceContainer* readAlignment(const std::string& path , const Alphabet* alpha) const throw (Exception)
+    AlignedSequenceContainer* readAlignment(const std::string& path , const Alphabet* alpha) const
     {
       return readAlignmentFromFile(path, alpha);
     }
  
     virtual
-    AlignedSequenceContainer* readAlignment(std::istream& input, const Alphabet* alpha) const throw (Exception)
+    AlignedSequenceContainer* readAlignment(std::istream& input, const Alphabet* alpha) const
     {
       return readAlignmentFromStream(input, alpha);
     }
@@ -121,7 +121,7 @@ class AbstractIAlignment:
      * @param sc     The sequence container to update.
      * @throw Exception If the file is not in the specified format.
      */
-    virtual void appendAlignmentFromStream(std::istream& input, SiteContainer& sc) const throw (Exception) = 0;
+    virtual void appendAlignmentFromStream(std::istream& input, SiteContainer& sc) const = 0;
   
     /**
      * @brief Append sequences to a container from a file.
@@ -130,7 +130,7 @@ class AbstractIAlignment:
      * @param sc    The sequence container to update.
      * @throw Exception If the file is not in the specified format.
      */
-    virtual void appendAlignmentFromFile(const std::string& path, SiteContainer& sc) const throw (Exception)
+    virtual void appendAlignmentFromFile(const std::string& path, SiteContainer& sc) const
     {
       std::ifstream input(path.c_str(), std::ios::in);
       appendAlignmentFromStream(input, sc);
@@ -145,7 +145,7 @@ class AbstractIAlignment:
      * @return A sequence container.
      * @throw Exception If the file is not in the specified format.
      */
-    virtual AlignedSequenceContainer* readAlignmentFromStream(std::istream& input, const Alphabet* alpha) const throw (Exception)
+    virtual AlignedSequenceContainer* readAlignmentFromStream(std::istream& input, const Alphabet* alpha) const
     {
       AlignedSequenceContainer* asc = new AlignedSequenceContainer(alpha);
       appendAlignmentFromStream(input, *asc);
@@ -160,7 +160,7 @@ class AbstractIAlignment:
      * @return A sequence container.
      * @throw Exception If the file is not in the specified format.
      */
-    virtual AlignedSequenceContainer* readAlignmentFromFile(const std::string& path, const Alphabet* alpha) const throw (Exception)
+    virtual AlignedSequenceContainer* readAlignmentFromFile(const std::string& path, const Alphabet* alpha) const
     {
       AlignedSequenceContainer* asc = new AlignedSequenceContainer(alpha);
       appendAlignmentFromFile(path, *asc);
