@@ -81,7 +81,7 @@ namespace bpp
      * @return A new OAlignment object according to options specified.
      * @throw Exception if an error occured.
      */
-    OAlignment* read(const std::string& description) throw (Exception);
+    OAlignment* read(const std::string& description);
 
     /**
      * @return The arguments and their unparsed values from the last call of the read function, if there are any.
