@@ -98,7 +98,7 @@ class NexusIOSequence:
      *
      * @{
      */
-    void appendAlignmentFromStream(std::istream& input, SiteContainer& sc) const throw (Exception);
+    void appendAlignmentFromStream(std::istream& input, SiteContainer& sc) const;
     /** @} */
 
     /**
@@ -109,10 +109,10 @@ class NexusIOSequence:
      *
      * @{
      */
-    virtual SequenceContainer* readSequences(std::istream& input, const Alphabet* alpha) const throw (Exception) {
+    virtual SequenceContainer* readSequences(std::istream& input, const Alphabet* alpha) const {
       return readAlignment(input, alpha);
     }
-    virtual SequenceContainer* readSequences(const std::string& path, const Alphabet* alpha) const throw (Exception) {
+    virtual SequenceContainer* readSequences(const std::string& path, const Alphabet* alpha) const {
       return readAlignment(path, alpha);
     }
     /** @} */
@@ -141,7 +141,7 @@ class NexusIOSequence:
     
   private:
     //Reading tools:
-    const std::vector<std::string> splitNameAndSequence_(const std::string & s) const throw (Exception); 
+    const std::vector<std::string> splitNameAndSequence_(const std::string & s) const; 
 };
 
 } //end of namespace bpp.
