@@ -85,7 +85,7 @@ bool SequenceTools::areSequencesIdentical(const Sequence& seq1, const Sequence&
 
 /******************************************************************************/
 
-Sequence* SequenceTools::concatenate(const Sequence& seq1, const Sequence& seq2) throw (AlphabetMismatchException, Exception)
+Sequence* SequenceTools::concatenate(const Sequence& seq1, const Sequence& seq2)
 {
   // Sequence's alphabets matching verification
   if ((seq1.getAlphabet()->getAlphabetType()) != (seq2.getAlphabet()->getAlphabetType()))
@@ -105,15 +105,15 @@ Sequence* SequenceTools::concatenate(const Sequence& seq1, const Sequence& seq2)
 
 /******************************************************************************/
 
-Sequence& SequenceTools::complement(Sequence& seq) throw (AlphabetException)
+Sequence& SequenceTools::complement(Sequence& seq)
 {
   // Alphabet type checking
   NucleicAcidsReplication* NAR;
-  if (seq.getAlphabet()->getAlphabetType() == "DNA alphabet")
+  if (AlphabetTools::isDNAAlphabet(seq.getAlphabet()))
   {
     NAR = &DNARep_;
   }
-  else if (seq.getAlphabet()->getAlphabetType() == "RNA alphabet")
+  else if (AlphabetTools::isRNAAlphabet(seq.getAlphabet()))
   {
     NAR = &RNARep_;
   }
@@ -130,15 +130,15 @@ Sequence& SequenceTools::complement(Sequence& seq) throw (AlphabetException)
 
 /******************************************************************************/
 
-Sequence* SequenceTools::getComplement(const Sequence& sequence) throw (AlphabetException)
+Sequence* SequenceTools::getComplement(const Sequence& sequence)
 {
   // Alphabet type checking
   NucleicAcidsReplication* NAR;
-  if (sequence.getAlphabet()->getAlphabetType() == "DNA alphabet")
+  if (AlphabetTools::isDNAAlphabet(sequence.getAlphabet()))
   {
     NAR = &DNARep_;
   }
-  else if (sequence.getAlphabet()->getAlphabetType() == "RNA alphabet")
+  else if (AlphabetTools::isRNAAlphabet(sequence.getAlphabet()))
   {
     NAR = &RNARep_;
   }
@@ -152,10 +152,10 @@ Sequence* SequenceTools::getComplement(const Sequence& sequence) throw (Alphabet
 
 /******************************************************************************/
 
-Sequence* SequenceTools::transcript(const Sequence& sequence) throw (AlphabetException)
+Sequence* SequenceTools::transcript(const Sequence& sequence)
 {
   // Alphabet type checking
-  if (sequence.getAlphabet()->getAlphabetType() != "DNA alphabet")
+  if (AlphabetTools::isDNAAlphabet(sequence.getAlphabet()))
   {
     throw AlphabetException ("SequenceTools::transcript : Sequence must be DNA", sequence.getAlphabet());
   }
@@ -165,10 +165,10 @@ Sequence* SequenceTools::transcript(const Sequence& sequence) throw (AlphabetExc
 
 /******************************************************************************/
 
-Sequence* SequenceTools::reverseTranscript(const Sequence& sequence) throw (AlphabetException)
+Sequence* SequenceTools::reverseTranscript(const Sequence& sequence)
 {
   // Alphabet type checking
-  if (sequence.getAlphabet()->getAlphabetType() != "RNA alphabet")
+  if (AlphabetTools::isRNAAlphabet(sequence.getAlphabet()))
   {
     throw AlphabetException ("SequenceTools::reverseTranscript : Sequence must be RNA", sequence.getAlphabet());
   }
@@ -208,17 +208,17 @@ Sequence& SequenceTools::invertComplement(Sequence& seq)
 {
   // Alphabet type checking
   NucleicAcidsReplication* NAR;
-  if (seq.getAlphabet()->getAlphabetType() == "DNA alphabet")
+  if (AlphabetTools::isDNAAlphabet(seq.getAlphabet()))
   {
     NAR = &DNARep_;
   }
-  else if (seq.getAlphabet()->getAlphabetType() == "RNA alphabet")
+  else if (AlphabetTools::isRNAAlphabet(seq.getAlphabet()))
   {
     NAR = &RNARep_;
   }
   else
   {
-    throw AlphabetException("SequenceTools::complement: Sequence must be nucleic.", seq.getAlphabet());
+    throw AlphabetException("SequenceTools::invertComplement: Sequence must be nucleic.", seq.getAlphabet());
   }
   // for (size_t i = 0 ; i < seq.size() ; i++) {
   //  seq.setElement(i, NAR->translate(seq.getValue(i)));
@@ -242,7 +242,7 @@ Sequence& SequenceTools::invertComplement(Sequence& seq)
 
 /******************************************************************************/
 
-double SequenceTools::getPercentIdentity(const Sequence& seq1, const Sequence& seq2, bool ignoreGaps) throw (AlphabetMismatchException, SequenceNotAlignedException)
+double SequenceTools::getPercentIdentity(const Sequence& seq1, const Sequence& seq2, bool ignoreGaps)
 {
   if (seq1.getAlphabet()->getAlphabetType() != seq2.getAlphabet()->getAlphabetType())
     throw AlphabetMismatchException("SequenceTools::getPercentIdentity", seq1.getAlphabet(), seq2.getAlphabet());
@@ -362,7 +362,7 @@ void SequenceTools::removeGaps(Sequence& seq)
 
 /******************************************************************************/
 
-Sequence* SequenceTools::getSequenceWithoutStops(const Sequence& seq, const GeneticCode& gCode) throw (Exception)
+Sequence* SequenceTools::getSequenceWithoutStops(const Sequence& seq, const GeneticCode& gCode)
 {
   const CodonAlphabet* calpha = dynamic_cast<const CodonAlphabet*>(seq.getAlphabet());
   if (!calpha)
@@ -380,7 +380,7 @@ Sequence* SequenceTools::getSequenceWithoutStops(const Sequence& seq, const Gene
 
 /******************************************************************************/
 
-void SequenceTools::removeStops(Sequence& seq, const GeneticCode& gCode) throw (Exception)
+void SequenceTools::removeStops(Sequence& seq, const GeneticCode& gCode)
 {
   const CodonAlphabet* calpha = dynamic_cast<const CodonAlphabet*>(seq.getAlphabet());
   if (!calpha)
@@ -394,7 +394,7 @@ void SequenceTools::removeStops(Sequence& seq, const GeneticCode& gCode) throw (
 
 /******************************************************************************/
 
-void SequenceTools::replaceStopsWithGaps(Sequence& seq, const GeneticCode& gCode) throw (Exception)
+void SequenceTools::replaceStopsWithGaps(Sequence& seq, const GeneticCode& gCode)
 {
   const CodonAlphabet* calpha = dynamic_cast<const CodonAlphabet*>(seq.getAlphabet());
   if (!calpha)
@@ -410,7 +410,6 @@ void SequenceTools::replaceStopsWithGaps(Sequence& seq, const GeneticCode& gCode
 /******************************************************************************/
 
 BowkerTest* SequenceTools::bowkerTest(const Sequence& seq1, const Sequence& seq2)
-throw (SequenceNotAlignedException)
 {
   if (seq1.size() != seq2.size())
     throw SequenceNotAlignedException("SequenceTools::bowkerTest.", &seq2);
@@ -515,7 +514,7 @@ void SequenceTools::getPutativeHaplotypes(const Sequence& seq, std::vector<Seque
 
 /******************************************************************************/
 
-Sequence* SequenceTools::combineSequences(const Sequence& s1, const Sequence& s2) throw (AlphabetMismatchException)
+Sequence* SequenceTools::combineSequences(const Sequence& s1, const Sequence& s2)
 {
   if (s1.getAlphabet()->getAlphabetType() != s2.getAlphabet()->getAlphabetType())
   {
@@ -540,7 +539,7 @@ Sequence* SequenceTools::combineSequences(const Sequence& s1, const Sequence& s2
 
 /******************************************************************************/
 
-Sequence* SequenceTools::subtractHaplotype(const Sequence& s, const Sequence& h, string name, unsigned int level) throw (SequenceNotAlignedException)
+Sequence* SequenceTools::subtractHaplotype(const Sequence& s, const Sequence& h, string name, unsigned int level)
 {
   const Alphabet* alpha = s.getAlphabet();
   if (name.size() == 0)
@@ -574,10 +573,10 @@ Sequence* SequenceTools::subtractHaplotype(const Sequence& s, const Sequence& h,
 
 /******************************************************************************/
 
-Sequence* SequenceTools::RNYslice(const Sequence& seq, int ph) throw (AlphabetException)
+Sequence* SequenceTools::RNYslice(const Sequence& seq, int ph)
 {
   // Alphabet type checking
-  if (seq.getAlphabet()->getAlphabetType() != "DNA alphabet")
+  if (AlphabetTools::isDNAAlphabet(seq.getAlphabet()))
   {
     throw AlphabetException ("SequenceTools::transcript : Sequence must be DNA", seq.getAlphabet());
   }
@@ -616,10 +615,10 @@ Sequence* SequenceTools::RNYslice(const Sequence& seq, int ph) throw (AlphabetEx
   return sq;
 }
 
-Sequence* SequenceTools::RNYslice(const Sequence& seq) throw (AlphabetException)
+Sequence* SequenceTools::RNYslice(const Sequence& seq)
 {
   // Alphabet type checking
-  if (seq.getAlphabet()->getAlphabetType() != "DNA alphabet")
+  if (AlphabetTools::isDNAAlphabet(seq.getAlphabet()))
   {
     throw AlphabetException ("SequenceTools::transcript : Sequence must be DNA", seq.getAlphabet());
   }
